@@ -36,7 +36,7 @@ ConfigDialog::ConfigDialog(CsoundQt *parent, Options *options, ConfigLists *conf
 	: QDialog(parent), m_parent(parent), m_options(options), m_configlists(configlists)
 {
 	setupUi(this);
-	setMaximumSize(QApplication::desktop()->width(),QApplication::desktop()->height()); // don't expand over screen
+    setMaximumSize(QApplication::desktop()->width()*0.9,QApplication::desktop()->height()*0.9); // don't expand over screen, leave some room for panels
 
 	m_configlists->refreshModules();
 
@@ -171,6 +171,7 @@ ConfigDialog::ConfigDialog(CsoundQt *parent, Options *options, ConfigLists *conf
 	openPropertiesCheckBox->setChecked(m_options->openProperties);
 	fontScalingSpinBox->setValue(m_options->fontScaling);
 	fontOffsetSpinBox->setValue(m_options->fontOffset);
+    tabShortcutActiveCheckBox->setChecked(m_options->tabShortcutActive);
 
 	if (m_options->useAPI)
 		ApiRadioButton->setChecked(true);
@@ -235,6 +236,7 @@ ConfigDialog::ConfigDialog(CsoundQt *parent, Options *options, ConfigLists *conf
 	simultaneousCheckBox->setChecked(m_options->simultaneousRun);
 
 	sampleFormatComboBox->setCurrentIndex(m_options->sampleFormat);
+	debugPortSpinBox->setValue(m_options->debugPort);
 
 	CsdocdirLineEdit->setText(m_options->csdocdir);
 	OpcodedirCheckBox->setChecked(m_options->opcodedirActive);
@@ -386,7 +388,8 @@ void ConfigDialog::accept()
 	m_options->openProperties = openPropertiesCheckBox->isChecked();
 	m_options->fontScaling = fontScalingSpinBox->value();
 	m_options->fontOffset = fontOffsetSpinBox->value();
-
+	m_options->debugPort = debugPortSpinBox->value();
+    m_options->tabShortcutActive = tabShortcutActiveCheckBox->isChecked();
 	m_options->useAPI = ApiRadioButton->isChecked();
 	//  m_options->thread = threadCheckBox->isChecked();
 	m_options->keyRepeat = keyRepeatCheckBox->isChecked();
