@@ -71,7 +71,7 @@ void Console::appendMessage(QString msg)
 	messageLine.append(msg);
 
 	if (messageLine.contains("\n")) { // line finished, analyze it now
-//		 qDebug() << "Messageline: " << messageLine;
+//		 qDebug()  << "Messageline: " << messageLine;
         if (messageLine.contains("error:", Qt::CaseInsensitive) && messageLine.contains("line ")) {
             errorTexts.append(messageLine); // .remove("\n")
 			errorTexts.last().remove("\n");
@@ -164,10 +164,12 @@ void Console::contextMenuEvent(QContextMenuEvent *event)
 void Console::keyPressEvent(QKeyEvent *event)
 {
     if (!event->isAutoRepeat() || m_repeatKeys) {
-		QString key = event->text();
-		if (key != "") {
-			appendMessage(key);
-			emit keyPressed(key);
+		QString keyText = event->text();
+		if (!keyText.isEmpty()) {
+			appendMessage(keyText);
+			emit keyPressed(static_cast<int>(keyText[0].toLatin1()));
+		} else {
+			emit keyPressed(event->key());
 		}
 	}
 }
@@ -175,10 +177,12 @@ void Console::keyPressEvent(QKeyEvent *event)
 void Console::keyReleaseEvent(QKeyEvent *event)
 {
     if (!event->isAutoRepeat() || m_repeatKeys) {
-		QString key = event->text();
-		if (key != "") {
-			//           appendMessage("rel:" + key);
-			emit keyReleased(key);
+		QString keyText = event->text();
+		if (!keyText.isEmpty()) {
+			appendMessage(keyText);
+			emit keyReleased(static_cast<int>(keyText[0].toLatin1()));
+		} else {
+			emit keyReleased(event->key());
 		}
 	}
 }
@@ -203,7 +207,7 @@ DockConsole::~DockConsole()
 
 void DockConsole::copy()
 {
-	qDebug() << "DockConsole::copy()";
+	qDebug() ;
 	static_cast<Console *>(widget())->copy();
 }
 
