@@ -61,7 +61,7 @@ Options::Options(ConfigLists *configlists) :
 
 	useAPI = true;
 	enableWidgets = true;
-	widgetsIndependent = true;  // Widget layouts in Separate Window (instead of Dock Widget)
+    widgetsIndependent = false;  // Widget layouts in Separate Window (instead of Dock Widget)
 	keyRepeat = true;
 	debugLiveEvents = false;
 	consoleBufferSize = 1024;
@@ -85,11 +85,15 @@ Options::Options(ConfigLists *configlists) :
 #else
 	csoundExecutable = "csound ";
 #endif
-	logFile = "log.txt";
+    logFile = ""; // "log.txt"; - don't log by default...
 	sdkDir = "";
 	templateDir = "";
 	evalLanguage = CS_ORC;
 
+#ifdef USE_WEBENGINE
+	debugPort = 34711;
+#endif
+
 	// External applications
 	terminal = "";
 	browser = "";
@@ -99,7 +103,7 @@ Options::Options(ConfigLists *configlists) :
 	pdfviewer = "";
 	language = 0;  // Interface language
 
-	csdTemplate = "";
+    csdTemplate = QCS_DEFAULT_TEMPLATE ; // was: ""
 
 	// Csound Utilities options
 	cvInputName = "input.wav";
