@@ -56,6 +56,7 @@ public:
 	bool wrapLines;
 	bool autoComplete;
 	bool autoParameterMode;
+    bool tabShortcutActive;
 
 	bool showWidgetsOnRun;
 	bool showTooltips;
@@ -118,6 +119,9 @@ public:
 
 	QString csdTemplate;
 
+	quint16 debugPort;
+
+
 	// Csound Utilities options
 	QString cvInputName;
 	QString cvOutputName;
