@@ -171,6 +171,83 @@ QString QuteButton::getCabbageLine()
 	return line;
 }
 
+QString QuteButton::getQml()
+{
+	QString qml = QString();
+#ifdef  USE_WIDGET_MUTEX
+	widgetLock.lockForWrite();
+#endif
+	qml = "\tButton { \n";
+    //qml += QString("\t\tid: %1Button\n").arg(m_channel);
+	qml += QString("\t\tx: %1 * scaleItem.scale\n").arg(x());
+	qml += QString("\t\ty: %1 * scaleItem.scale\n").arg(y());
+	qml += QString("\t\twidth: %1 * scaleItem.scale\n").arg(width());
+	qml += QString("\t\theight: %1 * scaleItem.scale\n").arg(height());
+	qml += QString("\t\ttext: \"%1\"\n").arg( property("QCS_text").toString());
+	bool checkable = property("QCS_latch").toBool();
+	if (checkable) {
+		qml += "\t\tcheckable: true\n";
+	}
+
+	qml += QString("\t\tproperty double pressedValue: %1\n").arg(property("QCS_pressedValue").toDouble()); // to be used for pressing the button.
+
+	QString type = property("QCS_type").toString();
+	qml += QString("\t\tproperty bool isEnventButton: %1\n").arg( (type=="value" ? "false" : "true" )  );
+	if (type == "value") {
+		qml += QString(R"(
+		onPressedChanged: {
+            if (pressed) {
+				csound.setControlChannel("%1", pressedValue );
+			} else {
+				csound.setControlChannel("%1", 0 );
+			}
+		}
+				 )").arg(m_channel);
+	}
+
+
+	if (type == "event" || type == "pictevent") {
+		QString eventLine = property("QCS_eventLine").toString();
+        QString turnOffLine = QString();
+		if (property("QCS_latch").toBool() && eventLine.size() > 0) {
+			QStringList lineElements = eventLine.split(QRegExp("\\s"),QString::SkipEmptyParts);
+			if (lineElements.size() > 0 && lineElements[0] == "i") {
+				lineElements.removeAt(0); // Remove first element if it is "i"
+			}
+			else if (lineElements.size() > 0 && lineElements[0][0] == 'i') {
+				lineElements[0] = lineElements[0].mid(1); // Remove "i" character
+			}
+
+			// this code is necessary to let instruments with line like "i 1 0 -1" to be switched on and off by latched button
+			if (lineElements.size() > 2 && lineElements[2].toDouble() < 0) { // If duration is negative, use button to turn note on and off
+                if ( lineElements[0].startsWith("\"") || lineElements[0].startsWith("\'")  ) {
+                    //qDebug()<<"Stopping named instrument: " << lineElements[0];
+                    lineElements[0].insert(1,"-");
+                } else {
+                    lineElements[0].prepend("-");
+                }
+                lineElements.prepend("i");
+
+                turnOffLine = lineElements.join(" ");
+
+				qml +=  QString("onCheckedChanged: (checked) ? csound.readScore(\'%1\') : csound.readScore(\'%2\')")
+                        .arg(eventLine, turnOffLine); // if unchecked, turnOffLine should consist line to turn off the instrument
+			}
+		} else { // if not latched, use onClicked event
+			qml += QString("\t\tonClicked: csound.readScore(\'%1\') \n").arg(eventLine);
+		}
+	}
+
+
+	qml += "\t}\n";
+#ifdef  USE_WIDGET_MUTEX
+	widgetLock.unlock();
+#endif
+
+	return qml;
+
+}
+
 QString QuteButton::getWidgetXmlText()
 {
 	// Buttons are not implemented in blue
@@ -324,16 +401,23 @@ void QuteButton::setMidiValue(int value)
 			else if (lineElements.size() > 0 && lineElements[0][0] == 'i') {
 				lineElements[0] = lineElements[0].mid(1); // Remove "i" character
 			}
-			bool test = property("QCS_latch").toBool();
+			//bool test = property("QCS_latch").toBool();
 			if (lineElements.size() > 2 && lineElements[2].toDouble() < 0 && property("QCS_latch").toBool() ) { // If duration is negative, turn it off. But not when it is not a latched button!
 				lineElements[0].prepend("-");
 				lineElements.prepend("i");
 				emit(queueEventSignal(lineElements.join(" ")));
 			}
 		}
+	} else if ((type == "value" || type == "pictvalue") && newval == pressedVal) {
+			QStringList reservedChannels = QStringList() << "_Play" <<"_Stop" << "_Pause"
+														 << "_Render" << "_Browse1" << "_Browse2" << "_MBrowse";
+			if (reservedChannels.contains(m_channel)) {
+				buttonReleased();
+			}
 	}
 	QPair<QString, double> channelValue(m_channel, newval);
 	emit newValue(channelValue);
+
 }
 
 void QuteButton::refreshWidget()
