@@ -69,7 +69,7 @@ class EventSheet;
 class CsoundEngine;
 class MidiHandler;
 class MidiLearnDialog;
-#ifdef QCS_HTML5
+#if defined(QCS_QTHTML)
 class CsoundHtmlView;
 #endif
 
@@ -145,6 +145,9 @@ public:
 	void stkCheck();
 	// localServer
 	bool startServer();
+#if defined(QCS_QTHTML)
+	void updateHtmlView();
+#endif
 public slots:
 	int loadFile(QString fileName, bool runNow = false);
 	int loadFileFromSystem(QString fileName); // checks for m_options->autoPlay, if the function is called from other class
@@ -164,8 +167,11 @@ public slots:
 	void sendEvent(QString eventLine, double delay = 0);
 	void sendEvent(int index, QString line, double delay = 0);
 	void changePage(int index);
+	void pageLeft();
+	void pageRight();
 	void setWidgetTooltipsVisible(bool visible);
 	void closeExtraPanels(); // to close help and console panels when esc is pressed in the editor
+
 	//    void updateWidgets();
 	void openExample();
 	void openTemplate();
@@ -213,6 +219,7 @@ private slots:
 	void inToGet();
 	void updateCsladspaText();
 	void updateCabbageText();
+    void saveWidgetsToQml();
 	void setCurrentAudioFile(const QString fileName);
 	void openExternalEditor();
 	void openExternalPlayer();
@@ -271,6 +278,8 @@ private slots:
 	void onNewConnection(); // when new client is connecting to localServer
 	void onReadyRead(); // when message comes in
 	void disableInternalRtMidi();
+    void focusToTab(int tab);
+    void ambiguosShortcut();
 #ifdef QCS_DEBUGGER
 	void runDebugger();
 	void stopDebugger();
@@ -329,7 +338,7 @@ private:
 	QQuickWidget *m_virtualKeyboard, *m_tableEditor;
 	QPointer <QQuickWidget> m_virtualKeyboardPointer, m_tableEditorPointer; // to control, if the object is deleted
 #endif
-#ifdef QCS_HTML5
+#if defined(QCS_QTHTML)
 public: CsoundHtmlView *csoundHtmlView;
 #endif
 private:
@@ -386,7 +395,8 @@ private:
 	QAction *inToGetAct;
 	QAction *csladspaAct;
 	QAction *cabbageAct;
-	QAction *findAct;
+    QAction *qmlAct;
+    QAction *findAct;
 	QAction *findAgainAct;
 	QAction *configureAct;
 	QAction *setShortcutsAct;
@@ -402,12 +412,14 @@ private:
 	QAction *externalPlayerAct;
 	QAction *focusEditorAct;
 	QAction *showHelpAct;
+    QAction *raiseHelpAct;
 	QAction *showManualAct;
 	QAction *downloadManualAct;
 	QAction *showGenAct;
 	QAction *showOverviewAct;
 	QAction *showOpcodeQuickRefAct;
 	QAction *showConsoleAct;
+    QAction *raiseConsoleAct;
     QAction *viewFullScreenAct;
     QAction *viewEditorFullScreenAct;
     QAction *viewHtmlFullScreenAct;
@@ -418,8 +430,9 @@ private:
 #endif
 	QAction *showVirtualKeyboardAct;
 	QAction *showTableEditorAct;
-#ifdef QCS_HTML5
+#if defined(QCS_QTHTML)
 	QAction *showHtml5Act;
+    QAction *raiseHtml5Act;
 #endif
 	QAction *midiLearnAct;
 	QAction *splitViewAct;
@@ -438,10 +451,14 @@ private:
 	QAction *openDocumentationAct;
 	QAction *showUtilitiesAct;
 	QAction *showWidgetsAct;
+    QAction *raiseWidgetsAct;
 	QAction *showInspectorAct;
+    QAction *raiseInspectorAct;
 	QAction *showLiveEventsAct;
 	QAction *showPythonConsoleAct;
+    QAction *raisePythonConsoleAct;
 	QAction *showScratchPadAct;
+    QAction *raiseScratchPadAct;
 	QAction *commentAct;
 	//    QAction *uncommentAct;
 	QAction *indentAct;
@@ -458,6 +475,7 @@ private:
 	QAction *lineNumbersAct;
 	QAction *parameterModeAct;
 //	QAction *showParametersAct;
+    QSignalMapper *focusMapper;
 	int curPage;
 	int curCsdPage;  // To recall last csd visited
 	int configureTab; // Tab in last configure dialog accepted
