@@ -315,13 +315,68 @@ QString QuteText::getCabbageLine() // QuteText is used both for label and displa
 	if ( m_type == "label" ) 	{ // then it is a label
 		line += "text(\"" + property("QCS_label").toString() + "\") " ;
 	} else { // display
-		line += QString("range(-1000000000000,1000000000000,%1), ").arg(m_value); // set redicolously large min and max value and hope the user will use larger numbers...
+        line += QString("range(-1000000000000,1000000000000,%1), ").arg(m_value); // set redicolously large min and max value and hope the user will not use larger numbers...
 		line += "active(0)";
 	}
 #ifdef  USE_WIDGET_MUTEX
 	widgetLock.unlock();
 #endif
-	return line;
+    return line;
+}
+
+QString QuteText::getQml()
+{
+    QString qml = QString();
+#ifdef  USE_WIDGET_MUTEX
+    widgetLock.lockForWrite();
+#endif
+
+    if (m_type == "label" || m_type == "display") {
+
+        // check if it has background and border
+        bool hasBackground = property("QCS_bgcolormode").toBool();
+        bool hasBorder = (property("QCS_bordermode").toString() == "border");
+        QString color = property("QCS_color").value<QColor>().name();
+
+        qml += "\n\tRectangle {\n"; // place within rectangle
+        qml += QString("\t\tx: %1 * scaleItem.scale\n").arg(x());
+        qml += QString("\t\ty: %1  * scaleItem.scale\n").arg(y());
+        qml += QString("\t\twidth: %1 * scaleItem.scale\n").arg(width());
+        qml += QString("\t\theight: %1 * scaleItem.scale\n").arg(height());
+        QString bgColor = hasBackground ? property("QCS_bgcolor").value<QColor>().name() : "transparent";
+        qml += QString("\t\tcolor: \"%1\"\n").arg(bgColor);
+        if (hasBorder) {
+            qml += QString("\t\tborder.width: %1\n").arg(QString::number(property("QCS_borderwidth").toInt()));
+            qml += QString("\t\tradius: %1\n").arg(QString::number(property("QCS_borderradius").toInt()));
+            qml += QString("\t\tborder.color: \"%1\"\n").arg(color);
+        } else {
+            qml += "\n\tborder.width: 0";
+        }
+
+
+
+        qml += "\n\t\tLabel {\n";
+
+        if (m_type == "display" && !m_channel.isEmpty()) {
+            qml += QString("\t\t\tid: "+m_channel + "\n");    // display has a channel ad mark it as ID
+        }
+
+        qml += QString("\t\t\tanchors.centerIn: parent\n");
+        qml += QString("\t\t\tfont.pixelSize: %1 * scaleItem.scale\n").arg(property("QCS_fontsize").toString()); // is it OK on ndroid? not pointsize?
+        qml += QString("\t\t\ttext: \"%1\"\n").arg(property("QCS_label").toString());
+
+        qml += QString("\t\t\tcolor: \"%1\"\n").arg(color);
+        qml += QString("\t\tfont.family: \"%1\"\n").arg(property("QCS_font").toString());
+        // TODO: alignment
+        qml += "\t\t}\n"; // end label
+        qml += "\t}\n"; // end rectangle
+    }
+#ifdef  USE_WIDGET_MUTEX
+    widgetLock.unlock();
+#endif
+
+    return qml;
+
 }
 
 
@@ -409,6 +464,7 @@ void QuteText::createPropertiesDialog()
 	label->setText(tr("Font Size"));
 	layout->addWidget(label, 8, 0, Qt::AlignRight|Qt::AlignVCenter);
 	fontSize = new QSpinBox(dialog);
+	fontSize->setMaximum(999); // allow also very big fonts
 	layout->addWidget(fontSize,8, 1, Qt::AlignLeft|Qt::AlignVCenter);
 	label = new QLabel(dialog);
 	label->setText(tr("Border Radius"));
